@@ -1,25 +1,25 @@
 $(document).ready(() => {
     $('.seriesCheck').on('click', function () {
-        const serCheck = this;
+        const serCheck = this.checked;
 
         $('.seasonCheck:visible').each(function () {
-            this.checked = serCheck.checked;
+            this.checked = serCheck;
         });
 
         $('.epCheck:visible').each(function () {
-            this.checked = serCheck.checked;
+            this.checked = serCheck;
         });
     });
 
     $('.seasonCheck').on('click', function () {
-        const seasCheck = this;
+        const seasCheck = this.checked;
         const seasNo = $(seasCheck).attr('id');
 
         $('.epCheck:visible').each(function () {
             const epParts = $(this).attr('id').split('x');
 
             if (epParts[0] === seasNo) {
-                this.checked = seasCheck.checked;
+                this.checked = seasCheck;
             }
         });
     });
