@@ -17,7 +17,7 @@ def add_name(name, indexer_id=0):
     :param name: The show name to cache
     :param indexer_id: the TVDB id that this show should be cached with (can be None/0 for unknown)
     """
-    cache_db_con = db.DBConnection('cache.db')
+    cache_db_con = db.DBConnection("cache.db")
 
     # standardize the name we're using to account for small differences in providers
     name = helpers.full_sanitizeSceneName(name)
@@ -42,7 +42,7 @@ def clear_cache(indexerid=0):
     """
     Deletes all "unknown" entries from the cache (names with indexer_id of 0).
     """
-    cache_db_con = db.DBConnection('cache.db')
+    cache_db_con = db.DBConnection("cache.db")
     cache_db_con.action("DELETE FROM scene_names WHERE indexer_id = ? OR indexer_id = ?", (indexerid, 0))
 
     to_remove = [key for key, value in name_cache.items() if value in (0, indexerid)]
@@ -52,7 +52,7 @@ def clear_cache(indexerid=0):
 
 def save_all_cached_names():
     """Commit cache to database file"""
-    cache_db_con = db.DBConnection('cache.db')
+    cache_db_con = db.DBConnection("cache.db")
 
     for name, indexer_id in name_cache.items():
         cache_db_con.action("INSERT OR REPLACE INTO scene_names (indexer_id, name) VALUES (?, ?)", [indexer_id, name])
@@ -75,10 +75,12 @@ def build_name_cache(show=None):
         clear_cache(show.indexerid)
         for season in scene_exceptions.get_all_scene_exceptions(show.indexerid).values():
             for exception in season:
-                name_cache[helpers.full_sanitizeSceneName(exception['show_name'])] = int(show.indexerid)
+                name_cache[helpers.full_sanitizeSceneName(exception["show_name"])] = int(show.indexerid)
 
         name_cache[helpers.full_sanitizeSceneName(show.show_name)] = int(show.indexerid)
         if show.custom_name:
             name_cache[helpers.full_sanitizeSceneName(show.custom_name)] = int(show.indexerid)
 
-        logger.debug("Internal name cache for " + show.name + " set to: [ " + ', '.join([key for key, value in name_cache.items() if value == show.indexerid]) + " ]")
+        logger.debug(
+            "Internal name cache for " + show.name + " set to: [ " + ", ".join([key for key, value in name_cache.items() if value == show.indexerid]) + " ]"
+        )
