@@ -11,7 +11,6 @@ from sickchill.providers.torrent.TorrentProvider import TorrentProvider
 
 
 class Provider(TorrentProvider):
-
     def __init__(self):
 
         # Provider Init
@@ -26,14 +25,14 @@ class Provider(TorrentProvider):
         self.minleech = 0
 
         # URLs
-        self.url = 'https://www.thegft.org/'
+        self.url = "https://www.thegft.org/"
         self.urls = {
-            'login': self.url + 'loginsite.php',
-            'search': self.url + 'browse.php',
+            "login": self.url + "loginsite.php",
+            "search": self.url + "browse.php",
         }
 
         # Proper Strings
-        self.proper_strings = ['PROPER', 'REPACK', 'REAL']
+        self.proper_strings = ["PROPER", "REPACK", "REAL"]
 
         # Cache
         self.cache = tvcache.TVCache(self)
@@ -50,18 +49,18 @@ class Provider(TorrentProvider):
             return True
 
         login_params = {
-            'username': self.username,
-            'password': self.password,
+            "username": self.username,
+            "password": self.password,
         }
 
         # Initialize session with a GET to have cookies
-        self.get_url(self.url, returns='text')
-        response = self.get_url(self.urls['login'], post_data=login_params, returns='text')
+        self.get_url(self.url, returns="text")
+        response = self.get_url(self.urls["login"], post_data=login_params, returns="text")
         if not response:
             logger.warning("Unable to connect to provider")
             return False
 
-        if re.search('Username or password incorrect', response):
+        if re.search("Username or password incorrect", response):
             logger.warning("Invalid username or password. Check your settings")
             return False
 
@@ -75,23 +74,23 @@ class Provider(TorrentProvider):
         # https://www.thegft.org/browse.php?view=0&c26=1&c37=1&c19=1&c47=1&c17=1&c4=1&search=arrow
         # Search Params
         search_params = {
-            'view': 0,  # BROWSE
-            'c4': 1,  # TV/XVID
-            'c17': 1,  # TV/X264
-            'c19': 1,  # TV/DVDRIP
-            'c26': 1,  # TV/BLURAY
-            'c37': 1,  # TV/DVDR
-            'c47': 1,  # TV/SD
-            'search': '',
+            "view": 0,  # BROWSE
+            "c4": 1,  # TV/XVID
+            "c17": 1,  # TV/X264
+            "c19": 1,  # TV/DVDRIP
+            "c26": 1,  # TV/BLURAY
+            "c37": 1,  # TV/DVDR
+            "c47": 1,  # TV/SD
+            "search": "",
         }
 
         # Units
-        units = ['B', 'KB', 'MB', 'GB', 'TB', 'PB']
+        units = ["B", "KB", "MB", "GB", "TB", "PB"]
 
         def process_column_header(td):
-            result = ''
+            result = ""
             if td.a and td.a.img:
-                result = td.a.img.get('title', td.a.get_text(strip=True))
+                result = td.a.img.get("title", td.a.get_text(strip=True))
             if not result:
                 result = td.get_text(strip=True)
             return result
@@ -100,67 +99,66 @@ class Provider(TorrentProvider):
             items = []
             logger.debug(_("Search Mode: {mode}".format(mode=mode)))
 
-            for search_string in search_strings[mode]:
+            for search_string in {*search_strings[mode]}:
 
-                if mode != 'RSS':
-                    logger.debug("Search string: {0}".format
-                                 (search_string))
+                if mode != "RSS":
+                    logger.debug("Search string: {0}".format(search_string))
 
-                search_params['search'] = search_string
+                search_params["search"] = search_string
 
-                data = self.get_url(self.urls['search'], params=search_params, returns='text')
+                data = self.get_url(self.urls["search"], params=search_params, returns="text")
                 if not data:
                     logger.debug("No data returned from provider")
                     continue
 
-                with BS4Parser(data, 'html5lib') as html:
-                    torrent_table = html.find('div', id='torrentBrowse')
-                    torrent_rows = torrent_table('tr') if torrent_table else []
+                with BS4Parser(data, "html5lib") as html:
+                    torrent_table = html.find("div", id="torrentBrowse")
+                    torrent_rows = torrent_table("tr") if torrent_table else []
 
                     # Continue only if at least one Release is found
                     if len(torrent_rows) < 2:
                         logger.debug("Data returned from provider does not contain any torrents")
                         continue
 
-                    labels = [process_column_header(label) for label in torrent_rows[0]('td')]
+                    labels = [process_column_header(label) for label in torrent_rows[0]("td")]
 
                     # Skip column headers
                     for result in torrent_rows[1:]:
 
                         try:
-                            cells = result('td')
+                            cells = result("td")
 
-                            title = cells[labels.index('Name')].find('a').find_next('a')['title'] or cells[labels.index('Name')].find('a')['title']
-                            download_url = self.url + cells[labels.index('DL')].find('a')['href']
+                            title = cells[labels.index("Name")].find("a").find_next("a")["title"] or cells[labels.index("Name")].find("a")["title"]
+                            download_url = self.url + cells[labels.index("DL")].find("a")["href"]
                             if not all([title, download_url]):
                                 continue
 
-                            peers = cells[labels.index('S/L')].get_text(strip=True).split('/', 1)
+                            peers = cells[labels.index("S/L")].get_text(strip=True).split("/", 1)
                             seeders = try_int(peers[0])
                             leechers = try_int(peers[1])
 
                             # Filter unseeded torrent
                             if seeders < self.minseed or leechers < self.minleech:
-                                if mode != 'RSS':
-                                    logger.debug("Discarding torrent because it doesn't meet the"
-                                                 " minimum seeders or leechers: {0} (S:{1} L:{2})".format
-                                                 (title, seeders, leechers))
+                                if mode != "RSS":
+                                    logger.debug(
+                                        "Discarding torrent because it doesn't meet the"
+                                        " minimum seeders or leechers: {0} (S:{1} L:{2})".format(title, seeders, leechers)
+                                    )
                                 continue
 
-                            torrent_size = cells[labels.index('Size/Snatched')].get_text(strip=True).split('/', 1)[0]
+                            torrent_size = cells[labels.index("Size/Snatched")].get_text(strip=True).split("/", 1)[0]
                             size = convert_size(torrent_size, units=units) or -1
 
-                            item = {'title': title, 'link': download_url, 'size': size, 'seeders': seeders, 'leechers': leechers, 'hash': ''}
-                            if mode != 'RSS':
-                                logger.debug("Found result: {0} with {1} seeders and {2} leechers".format
-                                             (title, seeders, leechers))
+                            item = {"title": title, "link": download_url, "size": size, "seeders": seeders, "leechers": leechers, "hash": ""}
+                            if mode != "RSS":
+                                logger.debug("Found result: {0} with {1} seeders and {2} leechers".format(title, seeders, leechers))
 
                             items.append(item)
                         except Exception:
                             continue
 
             # For each search mode sort all the items by seeders if available
-            items.sort(key=lambda d: try_int(d.get('seeders', 0)), reverse=True)
+            items.sort(key=lambda d: try_int(d.get("seeders", 0)), reverse=True)
             results += items
 
         return results
