@@ -11,20 +11,19 @@ from sickchill.providers.torrent.TorrentProvider import TorrentProvider
 
 
 class Provider(TorrentProvider):
-
     def __init__(self):
 
         super().__init__("GimmePeers")
 
         self.urls = {
-            'base_url': 'https://www.gimmepeers.com',
-            'login': 'https://www.gimmepeers.com/takelogin.php',
-            'detail': 'https://www.gimmepeers.com/details.php?id=%s',
-            'search': 'https://www.gimmepeers.com/browse.php',
-            'download': 'https://gimmepeers.com/%s',
+            "base_url": "https://www.gimmepeers.com",
+            "login": "https://www.gimmepeers.com/takelogin.php",
+            "detail": "https://www.gimmepeers.com/details.php?id=%s",
+            "search": "https://www.gimmepeers.com/browse.php",
+            "download": "https://gimmepeers.com/%s",
         }
 
-        self.url = self.urls['base_url']
+        self.url = self.urls["base_url"]
 
         self.username = None
         self.password = None
@@ -35,7 +34,13 @@ class Provider(TorrentProvider):
 
         self.search_params = {
             # c20=1&c21=1&c25=1&c24=1&c23=1&c22=1&c1=1
-            "c20": 1, "c21": 1, "c25": 1, "c24": 1, "c23": 1, "c22": 1, "c1": 1
+            "c20": 1,
+            "c21": 1,
+            "c25": 1,
+            "c24": 1,
+            "c23": 1,
+            "c22": 1,
+            "c1": 1,
         }
 
     def _check_auth(self):
@@ -48,18 +53,14 @@ class Provider(TorrentProvider):
         if any(dict_from_cookiejar(self.session.cookies).values()):
             return True
 
-        login_params = {
-            'username': self.username,
-            'password': self.password,
-            'ssl': 'yes'
-        }
+        login_params = {"username": self.username, "password": self.password, "ssl": "yes"}
 
-        response = self.get_url(self.urls['login'], post_data=login_params, returns='text')
+        response = self.get_url(self.urls["login"], post_data=login_params, returns="text")
         if not response:
             logger.warning("Unable to connect to provider")
             return False
 
-        if re.search('Username or password incorrect!', response):
+        if re.search("Username or password incorrect!", response):
             logger.warning("Invalid username or password. Check your settings")
             return False
 
@@ -73,32 +74,31 @@ class Provider(TorrentProvider):
         for mode in search_strings:
             items = []
             logger.debug(_("Search Mode: {mode}".format(mode=mode)))
-            for search_string in search_strings[mode]:
-                if mode != 'RSS':
-                    logger.debug("Search string: {0}".format
-                                 (search_string))
+            for search_string in {*search_strings[mode]}:
+                if mode != "RSS":
+                    logger.debug("Search string: {0}".format(search_string))
 
-                self.search_params['search'] = search_string
+                self.search_params["search"] = search_string
 
-                data = self.get_url(self.urls['search'], params=self.search_params, returns='text')
+                data = self.get_url(self.urls["search"], params=self.search_params, returns="text")
                 if not data:
                     continue
 
                 # Checks if cookie has timed-out causing search to redirect to login page.
                 # If text matches on loginpage we login and generate a new cookie and load the search data again.
-                if re.search('Still need help logging in?', data):
+                if re.search("Still need help logging in?", data):
                     logger.debug("Login has timed out. Need to generate new cookie for GimmePeers and search again.")
                     self.session.cookies.clear()
                     self.login()
 
-                    data = self.get_url(self.urls['search'], params=self.search_params, returns='text')
+                    data = self.get_url(self.urls["search"], params=self.search_params, returns="text")
                     if not data:
                         continue
 
                 try:
                     with BS4Parser(data, "html.parser") as html:
-                        torrent_table = html.find('table', class_='browsetable')
-                        torrent_rows = torrent_table('tr') if torrent_table else []
+                        torrent_table = html.find("table", class_="browsetable")
+                        torrent_rows = torrent_table("tr") if torrent_table else []
 
                         # Continue only if one Release is found
                         if len(torrent_rows) < 2:
@@ -106,15 +106,15 @@ class Provider(TorrentProvider):
                             continue
 
                         for result in torrent_rows[1:]:
-                            cells = result('td')
+                            cells = result("td")
 
-                            link = cells[1].find('a')
-                            download_url = self.urls['download'] % cells[2].find('a')['href']
+                            link = cells[1].find("a")
+                            download_url = self.urls["download"] % cells[2].find("a")["href"]
 
                             try:
                                 title = link.getText()
-                                seeders = int(cells[10].getText().replace(',', ''))
-                                leechers = int(cells[11].getText().replace(',', ''))
+                                seeders = int(cells[10].getText().replace(",", ""))
+                                leechers = int(cells[11].getText().replace(",", ""))
                                 torrent_size = cells[8].getText()
                                 size = convert_size(torrent_size) or -1
                             except (AttributeError, TypeError):
@@ -125,16 +125,19 @@ class Provider(TorrentProvider):
 
                                 # Filter unseeded torrent
                             if seeders < self.minseed or leechers < self.minleech:
-                                if mode != 'RSS':
-                                    logger.debug("Discarding torrent because it doesn't meet the minimum seeders or leechers: {0} (S:{1} L:{2})".format
-                                                 (title, seeders, leechers))
+                                if mode != "RSS":
+                                    logger.debug(
+                                        "Discarding torrent because it doesn't meet the minimum seeders or leechers: {0} (S:{1} L:{2})".format(
+                                            title, seeders, leechers
+                                        )
+                                    )
                                 continue
 
                             if seeders >= 32768 or leechers >= 32768:
                                 continue
 
-                            item = {'title': title, 'link': download_url, 'size': size, 'seeders': seeders, 'leechers': leechers, 'hash': ''}
-                            if mode != 'RSS':
+                            item = {"title": title, "link": download_url, "size": size, "seeders": seeders, "leechers": leechers, "hash": ""}
+                            if mode != "RSS":
                                 logger.debug("Found result: {0} with {1} seeders and {2} leechers".format(title, seeders, leechers))
 
                             items.append(item)
@@ -143,7 +146,7 @@ class Provider(TorrentProvider):
                     logger.warning("Failed parsing provider. Traceback: {0}".format(traceback.format_exc()))
 
             # For each search mode sort all the items by seeders if available
-            items.sort(key=lambda d: try_int(d.get('seeders', 0)), reverse=True)
+            items.sort(key=lambda d: try_int(d.get("seeders", 0)), reverse=True)
 
             results += items
 
