@@ -10,7 +10,6 @@ from sickchill.providers.torrent.TorrentProvider import TorrentProvider
 
 
 class Provider(TorrentProvider):
-
     def __init__(self):
 
         super().__init__("Rarbg")
@@ -36,11 +35,7 @@ class Provider(TorrentProvider):
         if self.token and self.token_expires and datetime.datetime.now() < self.token_expires:
             return True
 
-        login_params = {
-            "get_token": "get_token",
-            "format": "json",
-            "app_id": "sickchill"
-        }
+        login_params = {"get_token": "get_token", "format": "json", "app_id": "sickchill"}
 
         response = self.get_url(self.urls["api"], params=login_params, returns="json")
         if not response:
@@ -82,26 +77,26 @@ class Provider(TorrentProvider):
                 search_params.pop("search_string", None)
                 search_params.pop("search_tvdb", None)
                 if settings.movie_list and settings.movie_list.query.count():
-                    search_params['category[]'] = ['17', '18']
+                    search_params["category[]"] = ["17", "18"]
                 else:
-                    search_params['category'] = ['tv']
+                    search_params["category"] = ["tv"]
             else:
-                search_params['category'] = ('tv', 'movies')[mode == 'Movie']
+                search_params["category"] = ("tv", "movies")[mode == "Movie"]
                 search_params["sort"] = self.sorting if self.sorting else "seeders"
                 search_params["mode"] = "search"
 
-                if ep_indexer == 'tvdb' and ep_indexerid:
+                if ep_indexer == "tvdb" and ep_indexerid:
                     search_params["search_tvdb"] = ep_indexerid
                 else:
                     search_params.pop("search_tvdb", None)
 
-            for search_string in search_strings[mode]:
+            for search_string in {*search_strings[mode]}:
                 if mode != "RSS":
-                    search_string = re.sub(r"\((\d{4})\)", r'\1', search_string).replace(' ', '.')
+                    search_string = re.sub(r"\((\d{4})\)", r"\1", search_string).replace(" ", ".")
                     search_params["search_string"] = search_string
                     logger.debug(_("Search String: {search_string}".format(search_string=search_string)))
 
-                time.sleep(cpu_presets[settings.CPU_PRESET])
+                time.sleep(cpu_presets[settings.CPU_PRESET] + 2)
                 data = self.get_url(self.urls["api"], params=search_params, returns="json")
                 if not isinstance(data, dict):
                     logger.debug("No data returned from provider")
@@ -132,9 +127,10 @@ class Provider(TorrentProvider):
                         leechers = item.pop("leechers")
                         if seeders < self.minseed or leechers < self.minleech:
                             if mode != "RSS":
-                                logger.debug("Discarding torrent because it doesn't meet the"
-                                             " minimum seeders or leechers: {0} (S:{1} L:{2})".format
-                                             (title, seeders, leechers))
+                                logger.debug(
+                                    "Discarding torrent because it doesn't meet the"
+                                    " minimum seeders or leechers: {0} (S:{1} L:{2})".format(title, seeders, leechers)
+                                )
                             continue
 
                         torrent_size = item.pop("size", -1)
@@ -142,10 +138,9 @@ class Provider(TorrentProvider):
                         torrent_hash = self.hash_from_magnet(download_url)
 
                         if mode != "RSS":
-                            logger.debug("Found result: {0} with {1} seeders and {2} leechers".format
-                                         (title, seeders, leechers))
+                            logger.debug("Found result: {0} with {1} seeders and {2} leechers".format(title, seeders, leechers))
 
-                        result = {'title': title, 'link': download_url, 'size': size, 'seeders': seeders, 'leechers': leechers, 'hash': torrent_hash}
+                        result = {"title": title, "link": download_url, "size": size, "seeders": seeders, "leechers": leechers, "hash": torrent_hash}
                         items.append(result)
                     except Exception as e:
                         logger.info(e)
@@ -153,7 +148,7 @@ class Provider(TorrentProvider):
                     continue
 
             # For each search mode sort all the items by seeders
-            items.sort(key=lambda d: try_int(d.get('seeders', 0)), reverse=True)
+            items.sort(key=lambda d: try_int(d.get("seeders", 0)), reverse=True)
             results += items
 
         return results
