@@ -20,12 +20,12 @@ def should_refresh(exception_list):
     :param exception_list: exception list to check if needs a refresh
     :return: True if refresh is needed
     """
-    seconds_per_day = 24*60*60
+    seconds_per_day = 24 * 60 * 60
 
-    cache_db_con = db.DBConnection('cache.db')
+    cache_db_con = db.DBConnection("cache.db")
     rows = cache_db_con.select("SELECT last_refreshed FROM scene_exceptions_refresh WHERE list = ?", [exception_list])
     if rows:
-        last_refresh = int(rows[0]['last_refreshed'])
+        last_refresh = int(rows[0]["last_refreshed"])
         return int(time.mktime(datetime.datetime.today().timetuple())) > last_refresh + seconds_per_day
     else:
         return True
@@ -37,12 +37,8 @@ def set_last_refresh(exception_list):
 
     :param exception_list: exception list to set refresh time
     """
-    cache_db_con = db.DBConnection('cache.db')
-    cache_db_con.upsert(
-        "scene_exceptions_refresh",
-        {'last_refreshed': int(time.mktime(datetime.datetime.today().timetuple()))},
-        {'list': exception_list}
-    )
+    cache_db_con = db.DBConnection("cache.db")
+    cache_db_con.upsert("scene_exceptions_refresh", {"last_refreshed": int(time.mktime(datetime.datetime.today().timetuple()))}, {"list": exception_list})
 
 
 def get_scene_exceptions(indexer_id, season=-1):
@@ -51,9 +47,8 @@ def get_scene_exceptions(indexer_id, season=-1):
     """
 
     if indexer_id not in exeptions_cache or season not in exeptions_cache[indexer_id]:
-        cache_db_con = db.DBConnection('cache.db')
-        exceptions = cache_db_con.select("SELECT show_name FROM scene_exceptions WHERE indexer_id = ? and season = ?",
-                                         [indexer_id, season])
+        cache_db_con = db.DBConnection("cache.db")
+        exceptions = cache_db_con.select("SELECT show_name FROM scene_exceptions WHERE indexer_id = ? and season = ?", [indexer_id, season])
         if exceptions:
             exeptions_list = list({cur_exception["show_name"] for cur_exception in exceptions})
             if indexer_id not in exeptions_cache:
@@ -82,17 +77,14 @@ def get_all_scene_exceptions(indexer_id):
     """
     all_exceptions_dict = {}
 
-    cache_db_con = db.DBConnection('cache.db')
+    cache_db_con = db.DBConnection("cache.db")
     exceptions = cache_db_con.select("SELECT show_name, season, custom FROM scene_exceptions WHERE indexer_id = ?", [indexer_id])
 
     if exceptions:
         for cur_exception in exceptions:
             if cur_exception["season"] not in all_exceptions_dict:
                 all_exceptions_dict[cur_exception["season"]] = []
-            all_exceptions_dict[cur_exception["season"]].append({
-                "show_name": cur_exception["show_name"],
-                "custom": bool(cur_exception["custom"])
-            })
+            all_exceptions_dict[cur_exception["season"]].append({"show_name": cur_exception["show_name"], "custom": bool(cur_exception["custom"])})
 
     shows = [show for show in settings.showList if show.indexerid == indexer_id]
     if len(shows) == 1:
@@ -100,15 +92,9 @@ def get_all_scene_exceptions(indexer_id):
         if -1 not in all_exceptions_dict and show.show_name or show.custom_name:
             all_exceptions_dict[-1] = []
         if show.show_name:
-            all_exceptions_dict[-1].append({
-                "show_name": helpers.full_sanitizeSceneName(show.show_name),
-                "custom": False
-            })
+            all_exceptions_dict[-1].append({"show_name": helpers.full_sanitizeSceneName(show.show_name), "custom": False})
         if show.custom_name:
-            all_exceptions_dict[-1].append({
-                "show_name": helpers.full_sanitizeSceneName(show.custom_name),
-                "custom": False
-            })
+            all_exceptions_dict[-1].append({"show_name": helpers.full_sanitizeSceneName(show.custom_name), "custom": False})
 
     return all_exceptions_dict
 
@@ -124,10 +110,8 @@ def get_scene_exception_by_name_multiple(show_name):
     """
 
     # try the obvious case first
-    cache_db_con = db.DBConnection('cache.db')
-    exception_result = cache_db_con.select(
-        "SELECT indexer_id, season FROM scene_exceptions WHERE LOWER(show_name) = ? ORDER BY season",
-        [show_name.lower()])
+    cache_db_con = db.DBConnection("cache.db")
+    exception_result = cache_db_con.select("SELECT indexer_id, season FROM scene_exceptions WHERE LOWER(show_name) = ? ORDER BY season", [show_name.lower()])
     if exception_result:
         return [(int(x["indexer_id"]), int(x["season"])) for x in exception_result]
 
@@ -139,12 +123,9 @@ def get_scene_exception_by_name_multiple(show_name):
         cur_exception_name = cur_exception["show_name"]
         cur_indexer_id = int(cur_exception["indexer_id"])
 
-        if show_name.lower() in (
-                cur_exception_name.lower(),
-                sickchill.oldbeard.helpers.sanitizeSceneName(cur_exception_name).lower().replace('.', ' ')):
+        if show_name.lower() in (cur_exception_name.lower(), sickchill.oldbeard.helpers.sanitizeSceneName(cur_exception_name).lower().replace(".", " ")):
 
-            logger.debug("Scene exception lookup got indexer id {0}, using that".format
-                         (cur_indexer_id))
+            logger.debug("Scene exception lookup got indexer id {0}, using that".format(cur_indexer_id))
 
             out.append((cur_indexer_id, int(cur_exception["season"])))
 
@@ -166,7 +147,7 @@ def retrieve_exceptions():  # pylint:disable=too-many-locals, too-many-branches
             do_refresh = True
 
     if do_refresh:
-        loc = 'https://sickchill.github.io/scene_exceptions/scene_exceptions.json'
+        loc = "https://sickchill.github.io/scene_exceptions/scene_exceptions.json"
         logger.info("Checking for scene exception updates from {0}".format(loc))
 
         session = helpers.make_session()
@@ -178,7 +159,7 @@ def retrieve_exceptions():  # pylint:disable=too-many-locals, too-many-branches
             }
 
         try:
-            jdata = helpers.getURL(loc, session=session, returns='json')
+            jdata = helpers.getURL(loc, session=session, returns="json")
         except Exception:
             jdata = None
 
@@ -219,7 +200,7 @@ def retrieve_exceptions():  # pylint:disable=too-many-locals, too-many-branches
             exception_dict[anidb_ex] = anidb_exception_dict[anidb_ex]
 
     queries = []
-    cache_db_con = db.DBConnection('cache.db')
+    cache_db_con = db.DBConnection("cache.db")
     for cur_indexer_id in exception_dict:
         sql_ex = cache_db_con.select("SELECT show_name FROM scene_exceptions WHERE indexer_id = ?;", [cur_indexer_id])
         existing_exceptions = [x["show_name"] for x in sql_ex]
@@ -230,8 +211,8 @@ def retrieve_exceptions():  # pylint:disable=too-many-locals, too-many-branches
             for cur_exception, cur_season in cur_exception_dict.items():
                 if cur_exception not in existing_exceptions:
                     queries.append(
-                        ["INSERT OR IGNORE INTO scene_exceptions (indexer_id, show_name, season) VALUES (?,?,?);",
-                         [cur_indexer_id, cur_exception, cur_season]])
+                        ["INSERT OR IGNORE INTO scene_exceptions (indexer_id, show_name, season) VALUES (?,?,?);", [cur_indexer_id, cur_exception, cur_season]]
+                    )
     if queries:
         cache_db_con.mass_action(queries)
         logger.debug("Updated scene exceptions")
@@ -246,21 +227,23 @@ def update_scene_exceptions(indexer_id, scene_exceptions):
     """
     Given a indexer_id, and a list of all show scene exceptions, update the db.
     """
-    cache_db_con = db.DBConnection('cache.db')
-    cache_db_con.action('DELETE FROM scene_exceptions WHERE indexer_id = ? and custom = 1', [indexer_id])
+    cache_db_con = db.DBConnection("cache.db")
+    cache_db_con.action("DELETE FROM scene_exceptions WHERE indexer_id = ? and custom = 1", [indexer_id])
 
     logger.info("Updating scene exceptions")
 
     for season in scene_exceptions:
         for cur_exception in scene_exceptions[season]:
-            cache_db_con.action("INSERT INTO scene_exceptions (indexer_id, show_name, season, custom) VALUES (?,?,?,?)",
-                                [indexer_id, cur_exception["show_name"], season, cur_exception["custom"]])
+            cache_db_con.action(
+                "INSERT INTO scene_exceptions (indexer_id, show_name, season, custom) VALUES (?,?,?,?)",
+                [indexer_id, cur_exception["show_name"], season, cur_exception["custom"]],
+            )
 
     rebuild_exception_cache(indexer_id)
 
 
 def _anidb_exceptions_fetcher():
-    if should_refresh('anidb'):
+    if should_refresh("anidb"):
         logger.info("Checking for scene exception updates for AniDB")
         for show in settings.showList:
             if show.is_anime and show.indexer == 1:
@@ -272,7 +255,7 @@ def _anidb_exceptions_fetcher():
                     if anime.name and anime.name != show.name:
                         anidb_exception_dict[show.indexerid] = [{anime.name: -1}]
 
-        set_last_refresh('anidb')
+        set_last_refresh("anidb")
     return anidb_exception_dict
 
 
@@ -280,37 +263,36 @@ xem_session = helpers.make_session()
 
 
 def _xem_exceptions_fetcher():
-    if should_refresh('xem'):
+    if should_refresh("xem"):
         for indexer, instance in sickchill.indexer:
             logger.info("Checking for XEM scene exception updates for {0}".format(instance.name))
 
             url = "http://thexem.de/map/allNames?origin={0}&seasonNumbers=1".format(instance.slug)
 
-            parsed_json = helpers.getURL(url, session=xem_session, timeout=90, returns='json')
+            parsed_json = helpers.getURL(url, session=xem_session, timeout=90, returns="json")
             if not parsed_json:
-                logger.debug("Check scene exceptions update failed for {0}, Unable to get URL: {1}".format
-                             ('theTVDB', url))
+                logger.debug("Check scene exceptions update failed for {0}, Unable to get URL: {1}".format("theTVDB", url))
                 continue
 
-            if parsed_json['result'] == 'failure':
+            if parsed_json["result"] == "failure":
                 continue
 
-            if parsed_json['data']:
-                for indexerid, names in parsed_json['data'].items():
+            if parsed_json["data"]:
+                for indexerid, names in parsed_json["data"].items():
                     try:
                         xem_exception_dict[int(indexerid)] = names
                     except Exception as error:
                         logger.warning("XEM: Rejected entry: indexerid:{0}; names:{1}".format(indexerid, names))
                         logger.debug("XEM: Rejected entry error message:{0}".format(error))
 
-        set_last_refresh('xem')
+        set_last_refresh("xem")
 
     return xem_exception_dict
 
 
 def rebuild_exception_cache(indexer_id):
-    cache_db_con = db.DBConnection('cache.db')
-    results = cache_db_con.action('SELECT show_name, season FROM scene_exceptions WHERE indexer_id = ?', [indexer_id])
+    cache_db_con = db.DBConnection("cache.db")
+    results = cache_db_con.action("SELECT show_name, season FROM scene_exceptions WHERE indexer_id = ?", [indexer_id])
 
     exceptions_cache_list = {}
     for result in results:
